@@ -3,6 +3,10 @@
 import os
 import sys
 
+from six import print_
+from six.moves import input, reduce
+
+
 TEST_DIR = os.path.dirname(os.path.realpath(__file__))
 ROOT_DIR = os.path.dirname(TEST_DIR)
 sys.path.insert(0, ROOT_DIR)
@@ -20,7 +24,6 @@ except ImportError:
 
     SCOPE_MAP = { 'basic': ['douban_basic_common', 'community_basic_user'], }
     SCOPE = ','.join(reduce(lambda x, y: x + y, SCOPE_MAP.values()))
-
     TOKEN = ''
 
 def get_client():
@@ -31,13 +34,13 @@ def get_client():
     if token:
         client.auth_with_token(token)
     else:
-        print 'Go to the following link in your browser:'
-        print client.authorize_url
+        print_('Go to the following link in your browser:')
+        print_(client.authorize_url)
 
-        code = raw_input('Enter the verification code and hit ENTER when you\'re done:')
+        code = input('Enter the verification code and hit ENTER when you\'re done:')
         client.auth_with_code(code)
-        print 'token code:', client.token_code
-        print 'refresh token code:', client.refresh_token_code
+        print_('token code:', client.token_code)
+        print_('refresh token code:', client.refresh_token_code)
     return client
 
 client = get_client()
