@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from framework import DoubanClientTestBase, DoubanError, main
+from framework import DoubanClientTestBase, DoubanAPIError, main
 
 class TestApiError(DoubanClientTestBase):
     pass
